import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { GuestCheckedInEnvelope, GuestCreatedEnvelope, GuestDeletedEnvelope, GuestEventCanceledEnvelope, GuestEventStartsEnvelope, GuestOrderCanceledEnvelope, GuestUpdatedEnvelope, GuestsQueryBuilder, QueryEventGuestsOptions } from './events-guests-v1-guest-guests.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function queryGuests(httpClient: HttpClient): QueryGuestsSignature;
interface QueryGuestsSignature {
    /**
     * Creates a query to retrieve a list of guests.
     *
     *
     * The `queryGuests()` method builds a query to retrieve a list of guests and returns a [GuestsQueryBuilder](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/ascending) object.
     *
     * The returned object contains the query definition which is typically used to run the query using the [`find()`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/find) method.
     *
     * You can refine the query by chaining `GuestsQueryBuilder` methods onto the query. `GuestsQueryBuilder` methods enable you to sort, filter, and control the results that `queryGuests.find()` returns.
     *
     * The query runs with the following `GuestsQueryBuilder` defaults that you can override:
     *
     * - [`skipTo(0)`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/skip-to)
     * - [`limit(50)`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/limit)
     * - [`descending("_createdDate")`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/descending)
     *
     * The methods that are chained to `queryGuests()` are applied in the order they are called. For example, if you apply `ascending ('_createdDate')` and then `descending ('_updatedDate')`, the results are sorted first by the created date and then, if there are multiple results with the same date, the items are sorted by the updated date.
     *
     * The table below shows which `GuestsQueryBuilder` methods are supported for `queryGuests()`. You can only use one filter method for each property. Only the first filter will work if a property is used in more than one filter.
     */
    (options?: QueryEventGuestsOptions | undefined): GuestsQueryBuilder;
}
export declare const onGuestCreated: EventDefinition<GuestCreatedEnvelope, "wix.events.guests.v1.guest_created">;
export declare const onGuestDeleted: EventDefinition<GuestDeletedEnvelope, "wix.events.guests.v1.guest_deleted">;
export declare const onGuestCheckedIn: EventDefinition<GuestCheckedInEnvelope, "wix.events.guests.v1.guest_guest_checked_in">;
export declare const onGuestEventCanceled: EventDefinition<GuestEventCanceledEnvelope, "wix.events.guests.v1.guest_guest_event_canceled">;
export declare const onGuestEventStarts: EventDefinition<GuestEventStartsEnvelope, "wix.events.guests.v1.guest_guest_event_starts">;
export declare const onGuestOrderCanceled: EventDefinition<GuestOrderCanceledEnvelope, "wix.events.guests.v1.guest_guest_order_canceled">;
export declare const onGuestUpdated: EventDefinition<GuestUpdatedEnvelope, "wix.events.guests.v1.guest_updated">;
export { ActionEvent, Address, AddressLocation, AddressStreetOneOf, AttendanceStatus, BaseEventMetadata, CheckIn, CommonAddress, CommonAddressLocation, CommonAddressStreetOneOf, CommonStreetAddress, CommonSubdivision, ContactEventStatusUpdated, CouponDiscount, CursorPaging, Cursors, DateAndTimeSettings, Discount, DiscountItem, DiscountItemDiscountOneOf, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventDeleted, EventDetails, EventGuest, EventMetadata, EventType, Fee, FeeName, FeeType, FormResponse, Formatted, FormattedAddress, GuestCheckedIn, GuestCheckedInEnvelope, GuestCount, GuestCountUpdate, GuestCountUpdated, GuestCreatedEnvelope, GuestDeletedEnvelope, GuestDetails, GuestEventCanceled, GuestEventCanceledEnvelope, GuestEventStarts, GuestEventStartsEnvelope, GuestListPreview, GuestOrderCanceled, GuestOrderCanceledEnvelope, GuestType, GuestUpdatedEnvelope, GuestsQueryBuilder, GuestsQueryResult, IdentificationData, IdentificationDataIdOneOf, InputValue, Invoice, Item, Language, ListGuestListPreviewsRequest, ListGuestListPreviewsResponse, Location, LocationType, MemberEventStatusUpdated, MemberEventStatusUpdatedEventType, MemberGuest, MemberGuests, MessageEnvelope, Money, NotifyActionType, NotifyGuestAction, Occurrence, OnlineConferencingLogin, OrderConfirmed, OrderDeleted, OrderDetails, OrderStatus, OrderType, OrderUpdated, Paging, PagingMetadataV2, PaidPlanDiscount, PaidPlanDiscountDiscountOneOf, PercentDiscount, QueryEventGuestsOptions, QueryEventGuestsRequest, QueryEventGuestsResponse, QueryV2, QueryV2PagingMethodOneOf, RecurrenceStatusStatus, Recurrences, RequestedFields, RequestedFieldsEnumRequestedFields, RestoreInfo, SecondaryLanguagesRequest, SecondaryLanguagesResponse, SortOrder, Sorting, StandardDetails, Status, StreamEventGuestsRequest, StreetAddress, Subdivision, SubdivisionSubdivisionType, SubdivisionType, Task, TaskContext, TaskKey, Tax, TaxType, Ticket, TicketDetails, TicketGuestDetails, Timing, UpdateGuestRequest, UpdateGuestResponse, WebhookIdentityType, } from './events-guests-v1-guest-guests.universal.js';
