import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTAddressToSDKAddress } from '@wix/sdk-runtime/transformations/address';
import { transformRESTFloatToSDKFloat } from '@wix/sdk-runtime/transformations/float';
import { transformRESTPageURLToSDKPageURL } from '@wix/sdk-runtime/transformations/page-url';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { queryGuests as universalQueryGuests, } from './events-guests-v1-guest-guests.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/events' };
export function queryGuests(httpClient) {
    return (options) => universalQueryGuests(options, 
    // @ts-ignore
    { httpClient });
}
export const onGuestCreated = EventDefinition('wix.events.guests.v1.guest_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.attendanceStatusUpdatedDate' },
            { path: 'entity.guestDetails.formResponse.inputValues.dateTime' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'entity.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'entity.guestDetails.formResponse.inputValues.address.address',
            },
        ],
    },
])))();
export const onGuestDeleted = EventDefinition('wix.events.guests.v1.guest_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.attendanceStatusUpdatedDate' },
            { path: 'entity.guestDetails.formResponse.inputValues.dateTime' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'entity.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'entity.guestDetails.formResponse.inputValues.address.address',
            },
        ],
    },
])))();
export const onGuestCheckedIn = EventDefinition('wix.events.guests.v1.guest_guest_checked_in', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.guest.createdDate' },
            { path: 'data.guest.updatedDate' },
            { path: 'data.guest.attendanceStatusUpdatedDate' },
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.dateTime',
            },
            { path: 'data.eventDetails.dateAndTimeSettings.startDate' },
            { path: 'data.eventDetails.dateAndTimeSettings.endDate' },
            {
                path: 'data.eventDetails.dateAndTimeSettings.recurringEvents.individualEventDates.startDate',
            },
            {
                path: 'data.eventDetails.dateAndTimeSettings.recurringEvents.individualEventDates.endDate',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'data.guest.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.address.address',
            },
            { path: 'data.eventDetails.location.address' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'data.eventDetails.eventPageUrl' }],
    },
])))();
export const onGuestEventCanceled = EventDefinition('wix.events.guests.v1.guest_guest_event_canceled', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.guest.createdDate' },
            { path: 'data.guest.updatedDate' },
            { path: 'data.guest.attendanceStatusUpdatedDate' },
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.dateTime',
            },
            { path: 'data.event.dateAndTimeSettings.startDate' },
            { path: 'data.event.dateAndTimeSettings.endDate' },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.startDate',
            },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.endDate',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'data.guest.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.address.address',
            },
            { path: 'data.event.location.address' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'data.event.eventPageUrl' }],
    },
])))();
export const onGuestEventStarts = EventDefinition('wix.events.guests.v1.guest_guest_event_starts', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.guest.createdDate' },
            { path: 'data.guest.updatedDate' },
            { path: 'data.guest.attendanceStatusUpdatedDate' },
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.dateTime',
            },
            { path: 'data.event.dateAndTimeSettings.startDate' },
            { path: 'data.event.dateAndTimeSettings.endDate' },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.startDate',
            },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.endDate',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'data.guest.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.address.address',
            },
            { path: 'data.event.location.address' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'data.event.eventPageUrl' }],
    },
])))();
export const onGuestOrderCanceled = EventDefinition('wix.events.guests.v1.guest_guest_order_canceled', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.guest.createdDate' },
            { path: 'data.guest.updatedDate' },
            { path: 'data.guest.attendanceStatusUpdatedDate' },
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.dateTime',
            },
            { path: 'data.event.dateAndTimeSettings.startDate' },
            { path: 'data.event.dateAndTimeSettings.endDate' },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.startDate',
            },
            {
                path: 'data.event.dateAndTimeSettings.recurringEvents.individualEventDates.endDate',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'data.guest.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'data.guest.guestDetails.formResponse.inputValues.address.address',
            },
            { path: 'data.event.location.address' },
        ],
    },
    {
        transformFn: transformRESTPageURLToSDKPageURL,
        paths: [{ path: 'data.event.eventPageUrl' }],
    },
])))();
export const onGuestUpdated = EventDefinition('wix.events.guests.v1.guest_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.attendanceStatusUpdatedDate' },
            { path: 'entity.guestDetails.formResponse.inputValues.dateTime' },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            { path: 'entity.guestDetails.formResponse.inputValues.number' },
        ],
    },
    {
        transformFn: transformRESTAddressToSDKAddress,
        paths: [
            {
                path: 'entity.guestDetails.formResponse.inputValues.address.address',
            },
        ],
    },
])))();
export { AttendanceStatus, EventType, FeeName, FeeType, GuestType, LocationType, MemberEventStatusUpdatedEventType, NotifyActionType, OrderStatus, OrderType, RecurrenceStatusStatus, RequestedFields, RequestedFieldsEnumRequestedFields, SortOrder, Status, SubdivisionSubdivisionType, SubdivisionType, TaxType, Timing, WebhookIdentityType, } from './events-guests-v1-guest-guests.universal.js';
//# sourceMappingURL=events-guests-v1-guest-guests.public.js.map